@@ -720,25 +720,6 @@ func TestCreateDeleteSecretAfterCR(t *testing.T) {
 
 }
 
-func TestBootstrapRemovedStillHaveSecret(t *testing.T) {
-	h, cfg, event := setup()
-	// mimic result if we bootstrapped as removed
-	cfg.Spec.ManagementState = operatorsv1api.Removed
-	cfg.Status.Version = h.version
-	event.Object = &corev1.Secret{
-		ObjectMeta: metav1.ObjectMeta{
-			Name:      coreosPullSecretName,
-			Namespace: coreosPullSecretNamespace,
-		},
-	}
-	h.secretclientwrapper.(*fakeSecretClientWrapper).err = nil
-	h.Handle(event)
-	importCred := util.Condition(cfg, v1.ImportCredentialsExist)
-	if importCred.Status != corev1.ConditionTrue {
-		t.Fatalf("import creds false: %#v", cfg)
-	}
-}
-
 func setup() (Handler, *v1.Config, util.Event) {
 	h := NewTestHandler()
 	cfg, _ := h.CreateDefaultResourceIfNeeded(nil)
@@ -807,23 +788,6 @@ func TestSecretAPIError(t *testing.T) {
 	validate(true, err, "", cfg, conditions, statuses, t)
 }
 
-func TestTemplateRemovedFromPayload(t *testing.T) {
-	h, _, _ := setup()
-	mimic(&h, x86OCPContentRootDir)
-
-	_, filePath, doUpsert, updateCfgOnly, err := h.prepSamplesWatchEvent("template", "no-longer-exists", map[string]string{}, false)
-	switch {
-	case len(filePath) > 0:
-		t.Fatalf("should not have returned a file path")
-	case doUpsert:
-		t.Fatalf("do upsert should not be true")
-	case updateCfgOnly:
-		t.Fatalf("update cfg only should not be true")
-	case err != nil:
-		t.Fatalf("got unexpected err %s", err.Error())
-	}
-}
-
 func TestImageStreamRemovedFromPayloadWithProgressingErrors(t *testing.T) {
 	h, cfg, _ := setup()
 	mimic(&h, x86OCPContentRootDir)
