@@ -28,7 +28,7 @@ import (
 	templateset "github.com/openshift/client-go/template/clientset/versioned"
 	samplesapi "github.com/openshift/api/samples/v1"
 	sampopclient "github.com/openshift/cluster-samples-operator/pkg/client"
-	sampleclientv1 "github.com/openshift/cluster-samples-operator/pkg/generated/clientset/versioned"
+	sampleclientv1 "github.com/openshift/client-go/samples/clientset/versioned"
 	operator "github.com/openshift/cluster-samples-operator/pkg/operatorstatus"
 	"github.com/openshift/cluster-samples-operator/pkg/stub"
 	"github.com/openshift/cluster-samples-operator/pkg/util"
@@ -859,7 +859,6 @@ func TestSpecManagementStateField(t *testing.T) {
 
 	verifyImageStreamsGone(t)
 	verifyTemplatesGone(t)
-	verifySecretPresent(t)
 
 	verifyClusterOperatorConditionsComplete(t, cfg.Status.Version, cfg.Status.ManagementState)
 
